@@ -1,5 +1,5 @@
 # sql/type_api.py
-# Copyright (C) 2005-2024 the SQLAlchemy authors and contributors
+# Copyright (C) 2005-2025 the SQLAlchemy authors and contributors
 # <see AUTHORS file>
 #
 # This module is part of SQLAlchemy and is released under
@@ -67,6 +67,7 @@ _T_con = TypeVar("_T_con", bound=Any, contravariant=True)
 _O = TypeVar("_O", bound=object)
 _TE = TypeVar("_TE", bound="TypeEngine[Any]")
 _CT = TypeVar("_CT", bound=Any)
+_RT = TypeVar("_RT", bound=Any)
 
 _MatchedOnType = Union[
     "GenericProtocol[Any]", TypeAliasType, NewType, Type[Any]
@@ -183,10 +184,27 @@ class TypeEngine(Visitable, Generic[_T]):
             self.expr = expr
             self.type = expr.type
 
+        def __reduce__(self) -> Any:
+            return self.__class__, (self.expr,)
+
+        @overload
+        def operate(
+            self,
+            op: OperatorType,
+            *other: Any,
+            result_type: Type[TypeEngine[_RT]],
+            **kwargs: Any,
+        ) -> ColumnElement[_RT]: ...
+
+        @overload
+        def operate(
+            self, op: OperatorType, *other: Any, **kwargs: Any
+        ) -> ColumnElement[_CT]: ...
+
         @util.preload_module("sqlalchemy.sql.default_comparator")
         def operate(
             self, op: OperatorType, *other: Any, **kwargs: Any
-        ) -> ColumnElement[_CT]:
+        ) -> ColumnElement[Any]:
             default_comparator = util.preloaded.sql_default_comparator
             op_fn, addtl_kw = default_comparator.operator_lookup[op.__name__]
             if kwargs:
@@ -308,11 +326,13 @@ class TypeEngine(Visitable, Generic[_T]):
         E.g.::
 
                 Table(
-                    'some_table', metadata,
+                    "some_table",
+                    metadata,
                     Column(
                         String(50).evaluates_none(),
                         nullable=True,
-                        server_default='no value')
+                        server_default="no value",
+                    ),
                 )
 
         The ORM uses this flag to indicate that a positive value of ``None``
@@ -638,7 +658,7 @@ class TypeEngine(Visitable, Generic[_T]):
             string_type = String()
 
             string_type = string_type.with_variant(
-                mysql.VARCHAR(collation='foo'), 'mysql', 'mariadb'
+                mysql.VARCHAR(collation="foo"), "mysql", "mariadb"
             )
 
         The variant mapping indicates that when this type is
@@ -1125,7 +1145,7 @@ class ExternalType(TypeEngineMixin):
     """
 
     cache_ok: Optional[bool] = None
-    """Indicate if statements using this :class:`.ExternalType` are "safe to
+    '''Indicate if statements using this :class:`.ExternalType` are "safe to
     cache".
 
     The default value ``None`` will emit a warning and then not allow caching
@@ -1166,12 +1186,12 @@ class ExternalType(TypeEngineMixin):
     series of tuples.   Given a previously un-cacheable type as::
 
         class LookupType(UserDefinedType):
-            '''a custom type that accepts a dictionary as a parameter.
+            """a custom type that accepts a dictionary as a parameter.
 
             this is the non-cacheable version, as "self.lookup" is not
             hashable.
 
-            '''
+            """
 
             def __init__(self, lookup):
                 self.lookup = lookup
@@ -1179,8 +1199,7 @@ class ExternalType(TypeEngineMixin):
             def get_col_spec(self, **kw):
                 return "VARCHAR(255)"
 
-            def bind_processor(self, dialect):
-                # ...  works with "self.lookup" ...
+            def bind_processor(self, dialect): ...  # works with "self.lookup" ...
 
     Where "lookup" is a dictionary.  The type will not be able to generate
     a cache key::
@@ -1216,7 +1235,7 @@ class ExternalType(TypeEngineMixin):
     to the ".lookup" attribute::
 
         class LookupType(UserDefinedType):
-            '''a custom type that accepts a dictionary as a parameter.
+            """a custom type that accepts a dictionary as a parameter.
 
             The dictionary is stored both as itself in a private variable,
             and published in a public variable as a sorted tuple of tuples,
@@ -1224,7 +1243,7 @@ class ExternalType(TypeEngineMixin):
             two equivalent dictionaries.  Note it assumes the keys and
             values of the dictionary are themselves hashable.
 
-            '''
+            """
 
             cache_ok = True
 
@@ -1233,15 +1252,12 @@ class ExternalType(TypeEngineMixin):
 
                 # assume keys/values of "lookup" are hashable; otherwise
                 # they would also need to be converted in some way here
-                self.lookup = tuple(
-                    (key, lookup[key]) for key in sorted(lookup)
-                )
+                self.lookup = tuple((key, lookup[key]) for key in sorted(lookup))
 
             def get_col_spec(self, **kw):
                 return "VARCHAR(255)"
 
-            def bind_processor(self, dialect):
-                # ...  works with "self._lookup" ...
+            def bind_processor(self, dialect): ...  # works with "self._lookup" ...
 
     Where above, the cache key for ``LookupType({"a": 10, "b": 20})`` will be::
 
@@ -1259,7 +1275,7 @@ class ExternalType(TypeEngineMixin):
 
         :ref:`sql_caching`
 
-    """  # noqa: E501
+    '''  # noqa: E501
 
     @util.non_memoized_property
     def _static_cache_key(
@@ -1301,10 +1317,11 @@ class UserDefinedType(
 
       import sqlalchemy.types as types
 
+
       class MyType(types.UserDefinedType):
           cache_ok = True
 
-          def __init__(self, precision = 8):
+          def __init__(self, precision=8):
               self.precision = precision
 
           def get_col_spec(self, **kw):
@@ -1313,19 +1330,23 @@ class UserDefinedType(
           def bind_processor(self, dialect):
               def process(value):
                   return value
+
               return process
 
           def result_processor(self, dialect, coltype):
               def process(value):
                   return value
+
               return process
 
     Once the type is made, it's immediately usable::
 
-      table = Table('foo', metadata_obj,
-          Column('id', Integer, primary_key=True),
-          Column('data', MyType(16))
-          )
+      table = Table(
+          "foo",
+          metadata_obj,
+          Column("id", Integer, primary_key=True),
+          Column("data", MyType(16)),
+      )
 
     The ``get_col_spec()`` method will in most cases receive a keyword
     argument ``type_expression`` which refers to the owning expression
@@ -1370,6 +1391,10 @@ class UserDefinedType(
 
         return self
 
+    if TYPE_CHECKING:
+
+        def get_col_spec(self, **kw: Any) -> str: ...
+
 
 class Emulated(TypeEngineMixin):
     """Mixin for base types that emulate the behavior of a DB-native type.
@@ -1490,7 +1515,7 @@ class NativeForEmulated(TypeEngineMixin):
 
 
 class TypeDecorator(SchemaEventTarget, ExternalType, TypeEngine[_T]):
-    """Allows the creation of types which add additional functionality
+    '''Allows the creation of types which add additional functionality
     to an existing type.
 
     This method is preferred to direct subclassing of SQLAlchemy's
@@ -1501,10 +1526,11 @@ class TypeDecorator(SchemaEventTarget, ExternalType, TypeEngine[_T]):
 
       import sqlalchemy.types as types
 
+
       class MyType(types.TypeDecorator):
-          '''Prefixes Unicode values with "PREFIX:" on the way in and
+          """Prefixes Unicode values with "PREFIX:" on the way in and
           strips it off on the way out.
-          '''
+          """
 
           impl = types.Unicode
 
@@ -1596,6 +1622,7 @@ class TypeDecorator(SchemaEventTarget, ExternalType, TypeEngine[_T]):
             from sqlalchemy import JSON
             from sqlalchemy import TypeDecorator
 
+
             class MyJsonType(TypeDecorator):
                 impl = JSON
 
@@ -1616,6 +1643,7 @@ class TypeDecorator(SchemaEventTarget, ExternalType, TypeEngine[_T]):
             from sqlalchemy import ARRAY
             from sqlalchemy import TypeDecorator
 
+
             class MyArrayType(TypeDecorator):
                 impl = ARRAY
 
@@ -1624,8 +1652,7 @@ class TypeDecorator(SchemaEventTarget, ExternalType, TypeEngine[_T]):
                 def coerce_compared_value(self, op, value):
                     return self.impl.coerce_compared_value(op, value)
 
-
-    """
+    '''
 
     __visit_name__ = "type_decorator"
 
@@ -1721,20 +1748,38 @@ class TypeDecorator(SchemaEventTarget, ExternalType, TypeEngine[_T]):
             kwargs["_python_is_types"] = self.expr.type.coerce_to_is_types
             return super().reverse_operate(op, other, **kwargs)
 
+    @staticmethod
+    def _reduce_td_comparator(
+        impl: TypeEngine[Any], expr: ColumnElement[_T]
+    ) -> Any:
+        return TypeDecorator._create_td_comparator_type(impl)(expr)
+
+    @staticmethod
+    def _create_td_comparator_type(
+        impl: TypeEngine[Any],
+    ) -> _ComparatorFactory[Any]:
+
+        def __reduce__(self: TypeDecorator.Comparator[Any]) -> Any:
+            return (TypeDecorator._reduce_td_comparator, (impl, self.expr))
+
+        return type(
+            "TDComparator",
+            (TypeDecorator.Comparator, impl.comparator_factory),  # type: ignore # noqa: E501
+            {"__reduce__": __reduce__},
+        )
+
     @property
     def comparator_factory(  # type: ignore  # mypy properties bug
         self,
     ) -> _ComparatorFactory[Any]:
         if TypeDecorator.Comparator in self.impl.comparator_factory.__mro__:  # type: ignore # noqa: E501
-            return self.impl.comparator_factory
+            return self.impl_instance.comparator_factory
         else:
             # reconcile the Comparator class on the impl with that
-            # of TypeDecorator
-            return type(
-                "TDComparator",
-                (TypeDecorator.Comparator, self.impl.comparator_factory),  # type: ignore # noqa: E501
-                {},
-            )
+            # of TypeDecorator.
+            # the use of multiple staticmethods is to support repeated
+            # pickling of the Comparator itself
+            return TypeDecorator._create_td_comparator_type(self.impl_instance)
 
     def _copy_with_check(self) -> Self:
         tt = self.copy()
@@ -2294,11 +2339,10 @@ def to_instance(
 
 
 def adapt_type(
-    typeobj: TypeEngine[Any],
+    typeobj: _TypeEngineArgument[Any],
     colspecs: Mapping[Type[Any], Type[TypeEngine[Any]]],
 ) -> TypeEngine[Any]:
-    if isinstance(typeobj, type):
-        typeobj = typeobj()
+    typeobj = to_instance(typeobj)
     for t in typeobj.__class__.__mro__[0:-1]:
         try:
             impltype = colspecs[t]
